@@ -32,6 +32,7 @@
 #include <gconf/gconf-client.h>
 #include <glade/glade-xml.h>
 #include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include <gtk/gtkliststore.h>
 #include "sj-extractor.h"
 
@@ -120,6 +121,11 @@ extern gboolean eject_finished;
  */
 extern gboolean autostart;
 
+/**
+ * Toggle, Title and Artist Renderers
+ */
+extern GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer;
+
 /**
  * GConf key names
  */
@@ -140,7 +146,21 @@ extern gboolean autostart;
 #define GCONF_HTTP_PROXY GCONF_PROXY_ROOT "/host"
 #define GCONF_HTTP_PROXY_PORT GCONF_PROXY_ROOT "/port"
 
+/**
+ * Custom stock icons
+ */
+#define SJ_STOCK_PLAYING "sj-stock-playing"
+#define SJ_STOCK_RECORDING "sj-stock-recording"
+#define SJ_STOCK_EXTRACT "sj-stock-extract"
+
 /* TODO: need to add a SjWindow object or something */
 void sj_main_set_title (const char* detail);
 
+/* Debug macros */
+#ifdef ENABLE_DEBUG
+#define d(x) x
+#else
+#define d(x)
+#endif
+
 #endif /* SOUND_JUICER_H */
